# Quick start

This is a quick start example of how to use the `vodex` library.
If you need more information on volumetric functional imaging,
and library structure, refer to Guide.
The data used in this tutorial is a [Toy Dataset](https://lemonjust.github.io/vodex/data/#toy-dataset).

Some code is also available as a [jupyter notebook](https://github.com/LemonJust/vodex/blob/main/notebooks/01_create_experiment_and_load_volumes.ipynb).

## Create Experiment
Create Experiment describes how to create a new experiment and save it to a database file for later use.

## Load Experiment
Load Experiment describes how to load a saved experiment from a database file.

## Load Volumes
Load Volumes describes how to load individual volumes with vodex.
